###########
poetry.lock
###########

``poetry.lock`` is a file generated by the `Poetry <https://python-poetry.org/>`_ dependency manager for Python projects. Poetry is a tool that simplifies Python package management and project dependency resolution. When you use Poetry to manage your project's dependencies, it creates a ``pyproject.toml`` file to specify project metadata and dependencies, and a ``poetry.lock`` file to lock down the exact versions of the dependencies.

By including the ``poetry.lock`` file in your version control system, e.g. Git, you ensure that all collaborators or deployment environments use the exact same versions of dependencies, minimizing potential compatibility issues and creating a reproducible environment.